@@ -16,7 +16,25 @@
 //! Most extensions to existing objects provide an `obj_with_extension.easy(&repo).an_easier_version_of_a_method()` or `easy(&repo)`
 //! method to hide all complex arguments and sacrifice some performance for a lot of convenience.
 //!
-//! When starting out, use `easy(…)` and migrate to the more detailed method signatures to squeeze out more performance.
+//! When starting out, use `easy(…)` and migrate to the more detailed method signatures to squeeze out the last inkling of performance
+//! if it really does make a difference.
+//!
+//! ## Object-Access Performance
+//!
+//! Accessing objects quickly is the bread-and-butter of working with git, right after accessing references. Hence it's vital
+//! to understand which cache levels exist and how to leverage them.
+//!
+//! When accessing an object, the first cache that's queried is a  memory-capped LRU object cache, mapping their id to data and kind.
+//! On miss, the object is looked up and if ia pack is hit, there is a small fixed-size cache for delta-base objects.
+//!
+//! In scenarios where the same objects are accessed multiple times, an object cache can be useful and is to be configured specifically
+//! using the [`object_cache_size(…)`][prelude::CacheAccessExt::object_cache_size()] method.
+//!
+//! Use the `cache-efficiency-debug` cargo feature to learn how efficient the cache actually is - it's easy to end up with lowered
+//! performance if the cache is not hit in 50% of the time.
+//!
+//! Environment variables can also be used for configuration if the application is calling
+//! [`apply_environment()`][prelude::CacheAccessExt::apply_environment()] on their `Easy*` accordingly.
 //!
 //! ### Shortcomings & Limitations
 //!
@@ -46,6 +64,9 @@
 //!   However, other ways to adjust the `Repository` of long-running applications are possible. For instance, there could be a flag that
 //!   indicates a new `Repository` should be created (for instance, after it was changed) which causes the next server connection to
 //!   create a new one. This instance is the one to use when spawning new `EasyArc` instances.
+//! * `Platform` types are used to hold mutable or shared versions of required state for use in dependent objects they create, like iterators.
+//!   These come with the benefit of allowing for nicely readable call chains. Sometimes these are called `Platform` for a lack of a more specific
+//!   term, some are called more specifically like `Ancestors`.
 //!
 //! ### Terminology
 //!
@@ -81,6 +102,7 @@
 //! * [`interrupt`]
 //! * [`protocol`]
 //!   * [`transport`][protocol::transport]
+//!     * [`packetline`][protocol::transport::packetline]
 //!
 #![deny(missing_docs, unsafe_code, rust_2018_idioms)]
 
@@ -89,15 +111,17 @@ use std::{path::PathBuf, rc::Rc, sync::Arc};
 // Re-exports to make this a potential one-stop shop crate avoiding people from having to reference various crates themselves.
 // This also means that their major version changes affect our major version, but that's alright as we directly expose their
 // APIs/instances anyway.
-pub use bstr;
 pub use git_actor as actor;
 #[cfg(all(feature = "unstable", feature = "git-diff"))]
 pub use git_diff as diff;
 #[cfg(feature = "unstable")]
 pub use git_features::{parallel, progress, progress::Progress};
 pub use git_hash as hash;
+#[doc(inline)]
+pub use git_hash::{oid, ObjectId};
 pub use git_lock as lock;
 pub use git_object as objs;
+pub use git_object::bstr;
 #[cfg(feature = "unstable")]
 pub use git_odb as odb;
 #[cfg(all(feature = "unstable", feature = "git-protocol"))]
@@ -109,6 +133,9 @@ pub use git_tempfile as tempfile;
 pub use git_traverse as traverse;
 #[cfg(all(feature = "unstable", feature = "git-url"))]
 pub use git_url as url;
+#[doc(inline)]
+#[cfg(all(feature = "unstable", feature = "git-url"))]
+pub use git_url::Url;
 
 pub mod interrupt;
 
@@ -125,7 +152,7 @@ pub mod prelude {
 pub mod path;
 
 mod repository;
-pub use repository::{discover, from_path, init, open};
+pub use repository::{discover, init, open};
 
 /// A repository path which either points to a work tree or the `.git` repository itself.
 #[derive(Debug, Clone, Eq, PartialEq, Ord, PartialOrd, Hash)]
